@@ -4,10 +4,16 @@
 """
 BaseTokenizer is a generic class making tools for later definition of more elaborated tokenizers. It deals only with the representation, and the way the `_subtokens_` of each children-classes are parsed by the `__getitem__` magic method.
 """
+import warnings
 
 from tokenspan import Span, Token, Tokens
 
-class BaseTokenizer():
+def _warning_tokens():
+    warnings.warn("prefer using tokens, this method will disapear after version 1.0",
+                  DeprecationWarning)
+    return None
+
+class BaseTokenizer(Span):
     """
 Define some standard functions for conversion from elaborated Tokenizer to Span, Token and Tokens classes. In sub-classes that inherits from this one, one should define a `_name_` attribute (that will be displayed on __repr__) and a `_subtokens_` entity that consists in a list of sub-entities that can be converted to Token, Span or String. 
 
@@ -18,25 +24,15 @@ Then the methods
 are automatically imported in the sub-classes.
     """
     
-    # def __repr__(self):
-    #     """Return the two main arguments (namely the `string` and the `ranges`) of the tokenizer constructed from this class instance."""
-    #     mess = "{}('{}', ".format(self.__class__.__name__, str(self))
-    #     mess += '['+','.join('('+str(r.start)+','+str(r.stop)+')' 
-    #                          for r in self.ranges)
-    #     mess += "])"
-    #     return mess
+    tokens = list()
     
     def tokenize(self, inplace=True):
         """Main method of the class. To be overwritten by the children classes."""
-        return NotImplementedError
-    @property
-    def _subtokens_(self):
-        """Sequence of sub-tokens. To be overwritten by the children classes."""
-        return NotImplementedError
+        raise NotImplementedError
     
     def __getitem__(self, n):
         """Returns the n element (eventually a slice) of the tokenizer, once the method `tokenize` has been applied. Requires that the tokenizer has the attribute `_subtokens_`."""
-        return self._subtokens_[n]
+        return self.tokens[n]
 
     def toSpans(self,):
         """Alias for to_spans method."""
@@ -48,11 +44,7 @@ Once `tokenize` method has been applied, this method transforms the `_subtokens_
 
 Returns a tuple of Span objects.
         """
-        spans = [Span(string=subtok.string,
-                      ranges=subtok.ranges,
-                      subtoksep=subtok.subtoksep)
-                 for subtok in self]
-        return tuple(spans)
+        return tuple(Span(subtok) for subtok in self)
     
     def toTokens(self, carry_attributes=True):
         """Alias for to_tokens method."""
