@@ -6,10 +6,10 @@ CharGrams class cuts a text on the characters (or any other regular expression p
 """
 
 import re
-from tokenspan import Span
 from .base_tokenizer import BaseTokenizer
+from .base_tokenizer import _warning_tokens
 
-class CharGrams(BaseTokenizer, Span):
+class CharGrams(BaseTokenizer):
     """
 CharGrams is a sub-class of Span. It allows cutting the text (given as string parameter) in a collection of sub-string that are characterized by their size.
                                                                                                                                          Basic examples are 
@@ -28,20 +28,6 @@ CharGrams(s,ranges=[range(1,3),range(4,6)],subtoksep='@').tokenize(size=2).toTok
 
 The main interests in the CharGrams class is to extract into Tokens objects, or Span objects the different tokens, in order to continue working on them.
     """
-    def __init__(self,
-                 string=str(),
-                 subtoksep=chr(32),
-                 ranges=None,):
-        """
-CharGrams has all the parameters of a Span object, namely `string` (the string to be tokenized), a `subtoksep` that will be inserted between the different sub-tokens of a Span object (default is a free space), and a `ranges` list of range objects. 
-        """
-        Span.__init__(self,string=string,subtoksep=subtoksep,ranges=ranges)
-        self.chargrams = list()
-        return None
-    
-    @property
-    def _subtokens_(self,):
-        return self.chargrams
     
     def __call__(self, 
                  string=str(),
@@ -59,7 +45,7 @@ Apply the `.tokenize` method to a new string. Returns a new `CharGrams` instance
     
     def tokenize(self, 
                  size=1, 
-                 step=1, 
+                 step=1,
                  inplace=True):
         """
 Tokenize the parent string into tokens, that are themselves instances of CharGrams.
@@ -73,12 +59,12 @@ Parameters :
 By default `CharGrams.tokenize().toStrings()` returns a list of characters.
         """
         if not inplace:
-            self = CharGrams(string=self.string,
-                             subtoksep=self.subtoksep,
-                             ranges=self.ranges)
-        chargrams = self.slice(start=0,stop=None,size=size,step=step)
-        self.chargrams = [CharGrams(self.string,
-                                    ranges=span.ranges,
-                                    subtoksep=self.subtoksep,)
-                          for span in chargrams]
+            self = self.__class__(self)
+        self.tokens = self.slice(start=0, stop=None, size=size, step=step)
         return self
+    
+    @property
+    def chargrams(self):
+        """Deprecated"""
+        _warning_tokens()
+        return self.tokens
