@@ -6,10 +6,11 @@ NGrams class cuts a text on the space (or any other regular expression pattern),
 """
 
 import re
-from tokenspan import Span
-from .base_tokenizer import BaseTokenizer
 
-class NGrams(BaseTokenizer,Span):
+from .base_tokenizer import BaseTokenizer
+from .base_tokenizer import _warning_tokens
+
+class NGrams(BaseTokenizer):
     """
 NGrams is a sub-class of Span. It allows cutting the text (given as string parameter) on the space (whatever its length, a space can also be a newline or a tabulation), and extracting the words in between these spaces. One can change the regular expression (REGEX) in order to cut the parent string into different Span objects. For instance
 
@@ -45,22 +46,6 @@ NGrams(s).tokenize().toStrings()
 # -> ['A', 'B', 'C', 'D']
 ```
     """
-    def __init__(self,
-                 string=str(),
-                 subtoksep=chr(32),
-                 ranges=None,
-                 regex='\s+'):
-        """
-NGrams has all the parameters of a Span object, namely `string` (the string to be tokenized), a `subtoksep` that will be inserted between the different sub-tokens of a Span object (default is a free space), and a `ranges` list of range objects.
-        """
-        Span.__init__(self,string=string,subtoksep=subtoksep,ranges=ranges)
-        self.regex = regex
-        self.ngrams = list()
-        return None
-    
-    @property
-    def _subtokens_(self,):
-        return self.ngrams
     
     def __call__(self, 
                  string=str(),
@@ -72,9 +57,9 @@ NGrams has all the parameters of a Span object, namely `string` (the string to b
         """
 Apply the `.tokenize` method to a new string. Returns a new `NGrams` instance. All parameters from `NGrams` and/or `NGrams.tokenize` are available, except `inplace`, which is always `False`.
         """
-        ng = NGrams(string=string,
-                    subtoksep=subtoksep,
-                    ranges=ranges)
+        ng = self.__class__(string=string,
+                            subtoksep=subtoksep,
+                            ranges=ranges)
         return ng.tokenize(ngram=ngram, regex=regex, flags=flags, inplace=False)
     
     def tokenize(self, ngram=1, regex='\s+', flags=0, inplace=True):
@@ -92,26 +77,26 @@ Parameters | Type | Details
 By default there is no flags (that is `flags=0`) and the `regex` is on space characters (that is `regex='\s+'`). In that case, `NGrams.tokenize().toStrings()` return words in a list (eventually the punctuations are glued to the string, e.g. `A string.` returns `['A', 'string.']`).
         """
         if not inplace:
-            self = NGrams(string=self.string,
-                          subtoksep=self.subtoksep,
-                          ranges=self.ranges,
-                          regex=self.regex)
-        self.regex = regex
+            self = self.__class__(self)
         removes = (range(r_.start+r.start(),r_.start+r.end()) 
                    for r_ in self.ranges
-                   for r in re.finditer(self.regex,
+                   for r in re.finditer(regex,
                                         self.string[r_.start:r_.stop],
                                         flags=flags))
         self.remove_ranges(removes)
         sub_spans = self.subspans
-        self.ngrams = []
+        self.tokens = []
         for i in range(len(sub_spans)-ngram+1):
             ranges = []
             for span in sub_spans[i:i+ngram]:
                 ranges.extend(span.ranges)
-            ngram_ = NGrams(self.string,
-                            ranges=ranges,
-                            subtoksep=self.subtoksep,
-                            regex=self.regex)
-            self.ngrams.append(ngram_)
+            ngram_ = self.__class__(self)
+            ngram_.ranges = ranges
+            self.tokens.append(ngram_)
         return self
+    
+    @property
+    def ngrams(self):
+        """Deprecated"""
+        _warning_tokens()
+        return self.tokens
