@@ -6,27 +6,16 @@ RegexDetector class cuts a text on any regular expression pattern, and returns t
 """
 
 import re
-from tokenspan import Span
-from .base_tokenizer import BaseTokenizer
 
-class RegexDetector(BaseTokenizer,Span):
+from tokenspan import Span
+
+from .base_tokenizer import BaseTokenizer
+from .base_tokenizer import _warning_tokens
+
+class RegexDetector(BaseTokenizer):
     """
 RegexDetector is a sub-class of Span. It allows cutting the text (given as string parameter) on any regular expression (REGEX), and extracting the resulting tokens from the parent string. The tokenized objects are themselves instances of RegexDetector, and one can thus applies REGEX expression recursively in the parent string.
     """
-    def __init__(self,
-                 string=str(),
-                 subtoksep=chr(32),
-                 ranges=None,):
-        """
-RegexDetector has all the parameters of a Span object, namely `string` (the string to be tokenized), a `subtoksep` that will be inserted between the different sub-tokens of a Span object (default is a free space), and a `ranges` list of range objects. 
-        """
-        Span.__init__(self,string=string,subtoksep=subtoksep,ranges=ranges)
-        self.detections = list()
-        return None
-
-    @property
-    def _subtokens_(self,):
-        return self.detections
     
     def __call__(self, 
                  string=str(),
@@ -37,12 +26,12 @@ RegexDetector has all the parameters of a Span object, namely `string` (the stri
         """
 Apply the `.tokenize` method to a new string. Returns a new `RegexDetector` instance. All parameters from `RegexDetector` and/or `RegexDetector.tokenize` are available, except `inplace`, which is always `False`.    
         """
-        rd = RegexDetector(string=string,
-                           subtoksep=substoksep,
-                           ranges=ranges)
+        rd = self.__class__(string=string,
+                            subtoksep=substoksep,
+                            ranges=ranges)
         return rd.tokenize(regex=regex, flags=flags, inplace=False)
     
-    def tokenize(self,regex='\w+',flags=0,inplace=True):
+    def tokenize(self, regex='\w+', flags=0, inplace=True):
         """
 Tokenize the parent string into tokens, that are themselves instances of RegexDetector (so for instance each of these instance can be searched by REGEX as well).
 Returns the RegexDetector object itself (tokenize is an in-place operation if `inplace=True`), or a new RegexDetector object. The different tokens are then stored in RegexDetector.subSpans list.
@@ -56,18 +45,18 @@ Parameters | Type | Details
 By default there is no flags (that is `flags=0`) and the `regex` is on contiguous alpha-numeric characters (that is `regex='\w+'`). In that case, `RegexDetector.tokenize().toStrings()` return words in a list.
         """
         if not inplace:
-            self = RegexDetector(string=self.string,
-                                 subtoksep=self.subtoksep,
-                                 ranges=self.ranges)
+            self = self.__class__(self)
         ranges = [range(r_.start+r.start(),r_.start+r.end())
                   for r_ in self.ranges
                   for r in re.finditer(regex,
                                        self.string[r_.start:r_.stop],
                                        flags=flags)]
         self.ranges = ranges
-        self.detections = []
-        for span in self.subspans:
-            self.detections.append(RegexDetector(string=self.string,
-                                                 subtoksep=self.subtoksep,
-                                                 ranges=span.ranges))
+        self.tokens = [self.__class__(span) for span in self.subspans]
         return self
+    
+    @property
+    def detections(self):
+        """Deprecated"""
+        _warning_tokens()
+        return self.tokens
